"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHighlightTypeForElement = exports.shouldElementHaveAddButton = exports.shouldElementHaveHighlight = exports.isElementAugmentable = exports.getAugmentableDescendants = exports.HighlightType = void 0;
const dataAttributes_1 = require("./dataAttributes");
const iframe_1 = require("./iframe");
var HighlightType;
(function (HighlightType) {
    HighlightType["None"] = "";
    HighlightType["Element"] = "element";
    HighlightType["ContentComponent"] = "content-component";
    HighlightType["ContentItem"] = "content-item";
})(HighlightType = exports.HighlightType || (exports.HighlightType = {}));
const ElementSelector = `*[${dataAttributes_1.DataAttribute.ElementCodename}]`;
const ContentComponentSelector = `*[${dataAttributes_1.DataAttribute.ComponentId}]:not([${dataAttributes_1.DataAttribute.ElementCodename}])`;
const ContentItemSelector = `*[${dataAttributes_1.DataAttribute.ItemId}]:not([${dataAttributes_1.DataAttribute.ComponentId}]):not([${dataAttributes_1.DataAttribute.ElementCodename}])`;
const ElementsWithAddButtonSelector = `*[${dataAttributes_1.MetadataAttribute.AddButton}]`;
const AllAugmentableElementsSelector = `${ElementSelector}, ${ContentComponentSelector}, ${ContentItemSelector}, ${ElementsWithAddButtonSelector}`;
/**
 * Find all descendant HTML elements that could be augmented (have highlights or add buttons near them).
 *
 * @param {HTMLElement | Document} node
 * @returns {NodeListOf<HTMLElement>}
 */
function getAugmentableDescendants(node) {
    if (iframe_1.isInsideIFrame()) {
        return node.querySelectorAll(AllAugmentableElementsSelector);
    }
    return node.querySelectorAll(ElementSelector);
}
exports.getAugmentableDescendants = getAugmentableDescendants;
/**
 * Checks if HTML element could be augmented (have highlights or add buttons near them).
 *
 * @param {HTMLElement | null} element
 * @returns {boolean}
 */
function isElementAugmentable(element) {
    return shouldElementHaveHighlight(element) || shouldElementHaveAddButton(element);
}
exports.isElementAugmentable = isElementAugmentable;
/**
 * Check if node should have highlights based on its data-attributes.
 *
 * @param {HTMLElement | null} element
 * @returns {boolean}
 */
function shouldElementHaveHighlight(element) {
    const highlightType = getHighlightTypeForElement(element);
    switch (highlightType) {
        case HighlightType.None:
            return false;
        case HighlightType.Element:
            return true;
        case HighlightType.ContentItem:
        case HighlightType.ContentComponent:
        default:
            return iframe_1.isInsideIFrame();
    }
}
exports.shouldElementHaveHighlight = shouldElementHaveHighlight;
/**
 * Check if node should have a add button based on its data-attributes.
 *
 * @param {HTMLElement | null} element
 * @returns {boolean}
 */
function shouldElementHaveAddButton(element) {
    // add button should only be visible inside an iframe
    return Boolean(iframe_1.isInsideIFrame() && element && element.hasAttribute(dataAttributes_1.MetadataAttribute.AddButton));
}
exports.shouldElementHaveAddButton = shouldElementHaveAddButton;
/**
 * Get HighlightType based on the HTML element data-attributes.
 *
 * @param {HTMLElement | null} element
 * @returns {HighlightType}
 */
function getHighlightTypeForElement(element) {
    if (!element) {
        return HighlightType.None;
    }
    // treat node as element if it has element codename attribute
    if (element.hasAttribute(dataAttributes_1.DataAttribute.ElementCodename)) {
        return HighlightType.Element;
    }
    // else treat node as content component if it has component id attribute
    else if (element.hasAttribute(dataAttributes_1.DataAttribute.ComponentId)) {
        return HighlightType.ContentComponent;
    }
    // else treat node as content item if it has item id attribute
    else if (element.hasAttribute(dataAttributes_1.DataAttribute.ItemId)) {
        return HighlightType.ContentItem;
    }
    return HighlightType.None;
}
exports.getHighlightTypeForElement = getHighlightTypeForElement;
//# sourceMappingURL=customElements.js.map